<?php

namespace App\Http\Livewire\Applications;



use App\Models\ApplicationB1;
use Livewire\Component;
use Illuminate\Support\Facades\Auth;
use Livewire\WithFileUploads;
use Storage;

class Appendixb1 extends Component
{
    use WithFileUploads;

    public ApplicationB1 $applicationB1;

    public $s14_students_file;
    public $s14_teachers_file;
    public $s15_file;

    public function mount($applicationB1) { $this->applicationB1 = $applicationB1; }

    

    protected $rules = [
        'applicationB1.s1' => 'max:500',
        'applicationB1.s2' => 'max:1500',
        'applicationB1.s3' => 'max:500',
        'applicationB1.s4' => 'max:200',
        'applicationB1.s5_name' => 'max:200',
        'applicationB1.s5_address' => 'max:500',
        'applicationB1.s5_contactperson_name' => 'max:200',
        'applicationB1.s5_contactperson_email' => 'max:200',
        'applicationB1.s5_contactperson_phone' => 'max:100',
        'applicationB1.s6' => 'max:500',
        'applicationB1.s7_np' => 'nullable',
        'applicationB1.s7_pr' => 'nullable',
        'applicationB1.s7_gym' => 'nullable',
        'applicationB1.s7_lyc' => 'nullable',
        'applicationB1.s7_epal' => 'nullable',
        'applicationB1.s7_eeeek' => 'nullable',
        'applicationB1.s7_enegyl' => 'nullable',
        'applicationB1.s7_sp_np' => 'nullable',
        'applicationB1.s7_sp_pr' => 'nullable',
        'applicationB1.s7_sp_gym' => 'nullable',
        'applicationB1.s7_sp_lyc' => 'nullable',
        'applicationB1.s7_music' => 'nullable',        
        'applicationB1.s7_church' => 'nullable',
        'applicationB1.s7_pr_classes' => 'nullable',
        'applicationB1.s7_gym_classes' => 'nullable',
        'applicationB1.s7_lyc_classes' => 'nullable',
        'applicationB1.s7_epal_classes' => 'nullable',
        'applicationB1.s7_area_country' => 'nullable',
        'applicationB1.s7_area' => 'nullable',
        'applicationB1.s8_inschool' => 'nullable',
        'applicationB1.s8_inschool_description' => 'nullable|max:200',
        'applicationB1.s8_offschool' => 'nullable',
        'applicationB1.s8_offschool_description' => 'nullable|max:200',
        'applicationB1.s9_anytime' => 'nullable',
        'applicationB1.s9_specifictime' => 'nullable',
        'applicationB1.s9_specifictime_description' => 'nullable|max:200',
        'applicationB1.s10' => 'max:500',
        'applicationB1.s11' => 'nullable',
        'applicationB1.s11_description' => 'nullable|max:200',
        'applicationB1.s12' => 'nullable',
        'applicationB1.s12_description' => 'nullable|max:1500',
        'applicationB1.s13' => 'nullable',
        'applicationB1.s14_students' => 'nullable',
        's14_students_file' => 'nullable|mimes:pdf|max:1048',
        'applicationB1.s14_teachers' => 'nullable',
        's14_teachers_file' => 'nullable|mimes:pdf|max:1048',
        'applicationB1.s14_interview' => 'nullable',
        'applicationB1.s14_other' => 'nullable',
        's15_file' => 'nullable|mimes:pdf|max:1048',
    ];

    public function updated($s15_file)
    {
        $this->validateOnly($s15_file);
        
    }

    public function save()
    {
        $this->validate();

        $this->applicationB1->save();
      
        if ($this->s15_file) $filename = $this->applicationB1->application_id . '-s15.'.$this->s15_file->extension();
        $this->s15_file && $this->applicationB1->update([
            's15_file' => $this->s15_file->storeAs('',  $filename, 'appendixa2'),
        ]);

        if ($this->s14_students_file) $filename = $this->applicationB1->application_id . '-s14st.'.$this->s14_students_file->extension();
        $this->s14_students_file && $this->applicationB1->update([
            's14_students_file' => $this->s14_students_file->storeAs('',  $filename, 'appendixa2'),
        ]);
        
        if ($this->s14_teachers_file)  $filename = $this->applicationB1->application_id . '-s14teach.'.$this->s14_teachers_file->extension();
        $this->s14_teachers_file && $this->applicationB1->update([
            's14_teachers_file' => $this->s14_teachers_file->storeAs('',  $filename, 'appendixa2'),
        ]);


        $this->emitSelf('notify-saved');
    }
    
    public function s14_students_fileExport()
    {
        return Storage::disk('appendixa2')->download($this->applicationB1->s14_students_file);
    }

    public function s14_teachers_fileExport()
    {
        return Storage::disk('appendixa2')->download($this->applicationB1->s14_teachers_file);
    }

    public function s15_fileExport()
    {
        return Storage::disk('appendixa2')->download($this->applicationB1->s15_file);
    }
}
