<?php

namespace App\Http\Livewire\Evaluator;

use Livewire\Component;
use App\Models\Application;
use App\Models\ApplicationA2;
use App\Models\ApplicationB1;
use App\Models\ApplicationHistory;
use App\Models\User;
use Illuminate\Support\Carbon;
use Illuminate\Support\Facades\Auth;
use App\Http\Livewire\DataTable\WithPerPagePagination;
use Mail;


class Applicationlist extends Component
{

    use WithPerPagePagination;

    public $showModificationModal = false;
    public $editing;
    public $mailAddress;

    public $search = '';
    public $sortField = 'date';
    public $sortDirection = 'desc';

    public function sortBy($field)
    {
        $this->sortDirection = $this->sortField === $field
            ? $this->sortDirection = $this->sortDirection === 'asc' ? 'desc' : 'asc'
            : 'asc';

        $this->sortField = $field;
    }
    
    public function tomodification(Application $application)
    {
        $this->showModificationModal = true;
        $this->editing = $application;
    }

    public function tomodificationupdate(Application $application)
    {

        $this->editing->status = 'Τροποποίηση';
        $this->editing->state = 4;
        $this->editing->date = now();
        $this->editing->save();

        $applicationCopy = $this->editing->replicate();
        $applicationCopy->status = 'Αντίγραφο';
        $applicationCopy->state = 6;
        $applicationCopy->original_id = $this->editing->id;
        $applicationCopy->save();

        $appA2 = ApplicationA2::where('application_id',$this->editing->id)->first();
        if ($appA2) {
            $appA2Copy = $appA2->replicate();
            $appA2Copy->application_id = $applicationCopy->id;
            $appA2Copy->save();
        }
        
        
        $appB1 = ApplicationB1::where('application_id',$this->editing->id)->first();
        if ($appB1) {
            $appB1Copy = $appB1->replicate();
            $appB1Copy->application_id = $applicationCopy->id;
            $appB1Copy->save();
        }

        //mail section
        $mailAddress = User::find($this->editing->user_id)->email;
        $data = array('name'=>"Ερευνητή", 
        'title' => $this->editing->title, 
        'name' => $this->editing->name, 
        'tmima' => $this->editing->tmima, 
        'email' => Auth::user()->email );
        Mail::send('mail', $data, function($message) use ($mailAddress) {
            $message->to($mailAddress, 'Ερευνητή')->subject
                ('Ενεργοποίηση τροποποίησης από χειριστή ΙΕΠ!');
            $message->from('research@request.gr','Έγκριση έρευνας');
        });

        //action section
        ApplicationHistory::create([
            'application_id' => $this->editing->id,
            'action' => 'Ενεργοποίηση τροποποίησης από χειριστή ΙΕΠ',
        ]);


        $this->showModificationModal = false;
    }    

    

    
       
    

    public function render()
    {
        $searchvalue = $this->search;
        $applications = Application::where('user_evaluator', Auth::user()->id)
        ->where(function($query) use ($searchvalue){
            $query->where('title','like', '%'.$searchvalue.'%')
                  ->orwhere('status','like', '%'.$searchvalue.'%');
        })
        ->orderBy($this->sortField, $this->sortDirection)
        ->paginate($this->perPage);
      
        return view('livewire.evaluator.applicationlist', [
            'applications' => $applications,
        ]);
    }


}
