<?php

namespace App\Http\Livewire\Ministry;

use Livewire\Component;
use App\Models\Application;
use App\Models\ApplicationHistory;
use App\Models\ApplicationIep;
use App\Models\User;
use Illuminate\Support\Carbon;
use Illuminate\Support\Facades\Auth;
use App\Http\Livewire\DataTable\WithPerPagePagination;
use Mail;



class Applicationlist extends Component
{

    use WithPerPagePagination;

    public $showDeleteModal = false;
    public $showIepModal = false;
    public $editing;
    public $mailAddress;

    public $search = '';
    public $sortField = 'date';
    public $sortDirection = 'desc';

    public function sortBy($field)
    {
        $this->sortDirection = $this->sortField === $field
            ? $this->sortDirection = $this->sortDirection === 'asc' ? 'desc' : 'asc'
            : 'asc';

        $this->sortField = $field;
    }

    public function confirm(Application $application)
    {
        $this->showDeleteModal = true;
        $this->editing = $application;
    }

    public function toiep(Application $application)
    {
        $this->showIepModal = true;
        $this->editing = $application;
    }

    public function delete(Application $application)
    {

      //  $application->delete();
        $this->editing->delete();
        $this->showDeleteModal = false;
    }

    public function toiepupdate(Application $application)
    {

        //$this->editing->delete();
        $this->editing->status = 'ΙΕΠ';
        $this->editing->state = 2;
        $this->editing-> date_assigned_ministry = now();
        $this->editing->save();
        
        //mail section
        $mailAddress = User::where('status',3)->first()->email;
        $data = array('name'=>"ΙΕΠ", 
        'title' => $this->editing->title, 
        'name' => $this->editing->name, 
        'tmima' => $this->editing->tmima, 
        'email' => Auth::user()->email );
        Mail::send('mail', $data, function($message) use ($mailAddress) {
            $message->to($mailAddress, 'ΙΕΠ')->subject
                ('Προώθηση αίτησης από ΥΠΑΙΘ!');
            $message->from('research@request.gr','Έγκριση έρευνας');
        });

        //action section
        ApplicationHistory::create([
            'application_id' => $this->editing->id,
            'action' => 'Προώθηση αίτησης στο ΙΕΠ',
        ]);

        
        //to parakato tha antikatastathei apo eggrafi sto imerologio kinisis tis aitisis
//        $newid = ApplicationIep::create([
//            'user_id' => Auth::id(),  
//            'application_id' => $this->editing->id,
//            'date_assigned_ministry' => now(),
//        ])->id;

        $this->showIepModal = false;
    }



    public function render()
    {
        $searchvalue = $this->search;
        $applications = Application::where('state','>',0) //h timi 0 einai to prosxedio kai den theloume na exei prosvasi to ypourgeio
        ->whereNull('original_id')
        ->where(function($query) use ($searchvalue){
            $query->where('title','like', '%'.$searchvalue.'%')
                  ->orwhere('status','like', '%'.$searchvalue.'%');
        })
        ->orderBy($this->sortField, $this->sortDirection)
        ->paginate($this->perPage);

        return view('livewire.ministry.applicationlist', [
            'applications' => $applications,
        ]);
    }


}
