<?php

namespace App\Models;

use Carbon\Carbon;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Storage;

class Application extends Model
{
    use HasFactory;

    protected $fillable = [
        'user_id',
        'title',
        'name',
        'eponimia',
        'phone',
        'website',
        'tmima',
        'date',
        'date_submitted',
        'date_assigned_ministry',
        'date_assigned_evaluator',
        'user_evaluator',
        'status',
        'state',    //0-prosxedio, 1-ypourgeio, 2-iep, 3-katatethike aitisi, 4-se tropopoiisi, 5-egkrithike/aporrifthike
        'report',
        'report_context',
        'report_proposal',
        'report_final',
        'report_file',
        'a3_file',
        'a4_file',
        'c2_file',
        'c3_file',
        'c4_file',
        'c5_file',
    ];

    protected $casts = [
        'date' => 'date',
        'date_submitted' => 'date',
        'date_assigned_ministry' => 'date',
        'date_assigned_evaluator' => 'date',
    ];

    public function getStatusColorAttribute()
    {
        return [
            'Υποβλήθηκε' => 'green',
            'Προσχέδιο' => 'orange',
            'Τροποποίηση' => 'red',
            'Έκθεση' => 'purple',
            'Εγκρίθηκε' => 'blue',
            'Τροποποιήθηκε' => 'yellow',
        ][$this->status] ?? 'cool-gray';
    }

    public function isuploadedReport_file()
    {
        return $this->report_file           
            ? true
            : false;
    }

    public function isuploadedA3_file()
    {
        return $this->a3_file           
            ? true
            : false;
    }

    public function isuploadedA4_file()
    {
        return $this->a4_file           
            ? true
            : false;
    }

    public function isuploadedC2_file()
    {
        return $this->c2_file           
            ? true
            : false;
    }

    public function isuploadedC3_file()
    {
        return $this->c3_file           
            ? true
            : false;
    }

    public function isuploadedC4_file()
    {
        return $this->c4_file           
            ? true
            : false;
    }

    public function isuploadedC5_file()
    {
        return $this->c5_file           
            ? true
            : false;
    }

    public function getDateForHumansAttribute()
    {
        return $this->date->format('d/m/Y');
    }
    public function getDateSubForHumansAttribute()
    {
        return $this->date_submitted->format('d, M Y');
    }
    public function getDateMinForHumansAttribute()
    {
        return $this->date_assigned_ministry->format('d, M Y');
    }
    public function getDateEvalForHumansAttribute()
    {
        return $this->date_assigned_evaluator->format('d, M Y');
    }

    public function getDateForEditingAttribute()
    {
        return $this->date->format('m/d/Y');
    }

    public function setDateForEditingAttribute($value)
    {
        $this->date = Carbon::parse($value);
    }


    public function user()
    {
        return $this->belongsTo('App\Models\User');
    }

    public function userevaluator()
    {
        return $this->belongsTo('App\Models\User', 'user_evaluator');
    }

    public function applicationsA2()
    {
        return $this->hasMany('App\Models\ApplicationA2');
    }

    public function applicationsB1()
    {
        return $this->hasMany('App\Models\ApplicationB1');
    }

    public function isSubmitted()
    {
        return $this->status == 'Υποβλήθηκε'          
            ? true
            : false;
    }

}
