<?php

namespace App\Models;

use Carbon\Carbon;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Storage;

class ApplicationIep extends Model
{
    use HasFactory;

    protected $table = 'applicationiep';

    protected $fillable = [
        'application_id',
        'date_assigned_ministry',
        'date_assigned_evaluator',
        'user_id',
        'comments',
    ];

    protected $casts = ['date_assigned_ministry' => 'date', 'date_assigned_evaluator' => 'date'];
    


    public function getDateMinForHumansAttribute()
    {
        return $this->date_assigned_ministry->format('d, M Y');
    }

    public function getDateMinForEditingAttribute()
    {
        return $this->date_assigned_ministry->format('m/d/Y');
    }

    public function setDateMinForEditingAttribute($value)
    {
        $this->date_assigned_ministry = Carbon::parse($value);
    }

    public function getDateEvalForHumansAttribute()
    {
        return $this->date_assigned_evaluator->format('d, M Y');
    }

    public function getDateEvalForEditingAttribute()
    {
        return $this->date_assigned_evaluator->format('m/d/Y');
    }

    public function setDateEvalForEditingAttribute($value)
    {
        $this->date_assigned_evaluator = Carbon::parse($value);
    }    

    public function application()
    {
        return $this->belongsTo('App\Models\Application');
    }

    public function user()
    {
        return $this->belongsTo('App\Models\User');
    }

}
