<?php

namespace App\Models;

use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Laravel\Fortify\TwoFactorAuthenticatable;
use Laravel\Jetstream\HasProfilePhoto;
use Laravel\Sanctum\HasApiTokens;

class User extends Authenticatable implements MustVerifyEmail
{
    use HasApiTokens;
    use HasFactory;
    use HasProfilePhoto;
    use Notifiable;
    use TwoFactorAuthenticatable;
    

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'name',
        'email',
        'password',
    ];

    /**
     * The attributes that should be hidden for arrays.
     *
     * @var array
     */
    protected $hidden = [
        'password',
        'remember_token',
        'two_factor_recovery_codes',
        'two_factor_secret',
        'status',
    ];

    public function role()
    {
        return $this->status;
    }
    
    public function roleCaption()
    {
//        return $this->status;
        switch($this->status) {
            case (1):
                return 'Admin';
            break;
            case (2):
                return 'Ministry';
            break;
            case (3):
                return 'IEP';
            break;
            case (4):
                return 'Evaluator';
            break;
            case (9):
                return 'Researcher';
            break;
        }

    }

    /**
     * The attributes that should be cast to native types.
     *
     * @var array
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
    ];

    /**
     * The accessors to append to the model's array form.
     *
     * @var array
     */
    protected $appends = [
        'profile_photo_url',
    ];

    public function applications()
    {
        return $this->hasMany('App\Models\Application');
    }

    public function isAdmin()
    {
        return $this->status == 1          
            ? true
            : false;
    }

    public function isResearcher() //o xristis poy kanei tin aitisi
    {
        return $this->status == 9          
            ? true
            : false;
    }

    public function isMinistry() //o xristis toy ypourgeiou
    {
        return $this->status == 2          
            ? true
            : false;
    }

    public function isIep() //o xristis toy ypourgeiou
    {
        return $this->status == 3          
            ? true
            : false;
    }

    public function isEvaluator() //o xristis toy ypourgeiou
    {
        return $this->status == 4     
            ? true
            : false;
    }    

    public function canEditApplication($application) //an exei dikaiomata na grapsei stis formes tis aitisis
    {
        return $this->status == 9 && ($application->status == 'Προσχέδιο' || $application->status == 'Τροποποίηση')
            ? true
            : false;
    }
}
